================================================================
Utforma ett webbaserat verktyg för riskbedömning – en vägledning
================================================================


1. Introduktion
===============

OIRA är ett webbaserat verktyg för riskbedömning. Du kan utforma och anpassa innehållet i OiRA-verktyget för företag inom din bransch och därmed erbjuda dem ett branschspecifikt verktyg. OiRA-verktyget är en metod för riskbedömning som består av fem olika steg:

  * **Förbereda** > branschen introducerar slutanvändarna (företagen) för riskbedömningen

  * **Identifiera** > slutanvändaren identifierar möjliga risker/problem /problemen genom att svara JA eller NEJ på ett antal frågor/påståeenden
 
  * **Värdera och bedöma** > slutanvändaren värderar och bedömer varje enskild risk som har identifierats

  * **Handlingsplan** > slutanvändaren gör en handlingsplan som behandlar alla värderade risker

  * **Rapport** > Handlingsplanen blir en skriftlig rapport som kan laddas ner och skrivas ut

1.1 Tänk på slutanvändarna
--------------------------

Det är viktigt att **tänka på vem slutanvändarna är (mikro/småföretag, abetsgivare/arbetstagare) och hur strukturen** för riskbedömningsverktyget ska se ut. Strukturen ska vara så relevant som möjligt för företagens dagliga aktiviteter. Ofta skiljer sig expertens tankesätt från slutanvändarens. Slutanvändaren tänker utifrån sina egna arbetsprocesser och utgår från sin verklighet. Här följer några exempel.
Ofta skiljer sig expertens tankesätt från slutanvändarens. Slutanvändaren tänker utifrån sina egna arbetsprocesser och använder sitt eget språk. Här följer några exempel:

  * ο experten tänker på fysisk arbetsbelastning medan, *slutanvändaren tänker på kroppsligt ansträngande arbete*

  * ο experten tänker på den termiska miljön, *Slutanvändaren, däremot, tänkerpå hur varmt eller kallt det får vara*

  * ο experten tänker på säkerheten och skapar en modul som innehåller allt inom detta område, *Slutanvändaren tänker på öppning och stängning av en butik och hur aggressiva kunder bör hanteras* 

1.2 Använd ett enkelt språk
---------------------------

**Om verktyget för riskbedömning struktureras så att det motsvarar användarens vardag** blir innehållet lätt att känna igen.  Det blir också enklare att ta fram en handlingsplan som är rimlig för den specifika arbetsplatsen.
  
En annan viktig aspekt är språket som används. **Språket** ska vara lätt att förstå utan att behöva tolkas och terminologin ska  vara välkänd av företagen.

Det är viktigt med korta meningar (och ett tydligt och enkelt vardagsspråk för att  r företaget ska kunna göra en riskbedömning och använda OiRA-verktyget på rätt sätt.

Du som anpassar verktyget har möjlighet att att inleda med eb  kort inledningstext.  Den bör vara  positiv och uppmuntrande och särskilt poängtera:

  * **vikten** av riskbedömningen

  * det faktum att riskbedömningen  **inte är komplicerad** (tanken är att du ska avdramatisera själva riskbedömningen)

  * det faktum att verktyget har utvecklats särskilt för att **uppfylla företagens särskilda behov** 


Det är viktigt att texten inte är för lång, annars kan slutanvändaren dra sig för att använda verktyget.

2. Team
=======

Det är viktigt att projektteamet har en lämplig storlek och det ska helst bestå av:

  * representanter för branschorganisationerna

  * representanter för fackföreningarna

  * OiRA-utvecklaren
 
  * en expert på säkerhet och hälsa på arbetsplatsen (med kunskap och erfarenhet av branschen)

  * slutanvändare (t.ex. ledning eller medarbetare från företag, skyddsombud, ...)
 

3. Struktur
===========

3.1 Strukturera innehållet hierarkiskt
--------------------------------------

Innan du börjar att anpassa OiRA-verktyget bör du fundera över antalet frågor. Det lönar sig att fundera grundligt över strukturen. Tänk på att gruppera frågeområdena på ett sätt som är relevant för slutanvändarna. 

I verktyget kan du gruppera områden, underliggande områden olika typer av risker. Syftet med grupperingen är att underlätta för slutanvändaren. Ditt OiRA-verktyg kommer därför att innehålla:
 
 
.. image:: ../images/creation/module.png 
  :align: left
  :height: 32 px
  
**MODULER** = områden (platser, aktiviteter …)
  
  *Exempel*: 
    Modul 1: *Schamponering*  (frisörsalong)
  
  .. image:: ../images/creation/submodule.png 
    :align: left
    :height: 32 px
    
  **UNDERMODULER** (ej obligatoriska) = underliggande områden
  
    *Exempel*: 
      Undermodul 1: *Arbetsställning*
      
      Undermodul 2: *Kontakt med vatten och kosmetikprodukter*
    
    .. image:: ../images/creation/risk.png 
      :align: left
      :height: 32 px
      
    **RISKER** = påståenden om en situation som är korrekt
    
      *Exempel*: 
        *1.1 Platsen för schamponering  kan justeras efter behov*
        
        *2.1 Lämplig skyddsutrustning, exempelvis engångshandskar, har köpts in*
      
      .. image:: ../images/creation/solution.png 
        :align: left
        :height: 32 px
        
      **ÅTGÄRDER** = Förebyggande åtgärder som löser problemet enligt expertens rekommendationer
      
        *Exempel*: 
          *1.1 Ta regelbundna raster för återhämtning efter fysiskt arbete*

          *2.1 Använd dammfria produkter*


Verktyget ger även möjlighet att:

  * hoppa över en modul/en uppsättning moduler om innehållet inte är relevanta för företaget

  * upprepa vissa moduler för företag som bedriver verksamhet på flera platser.

3.2 Betrakta risken som ett påstående
------------------------------------------------

När du har bestämt dig för huvudstrukturen för verktyget kan du börja att identifiera och förklara de olika riskerna.
 
Verktyget fungerar som **bekräftande påståenden**, dvs. det anger **om en situation är korrekt (målet som ska nås) eller inte**
 
 ..

   Exempel: Belysningen är rätt utformad.

Slutanvändarens svar är ett tydligt ”ja” eller ”nej”. Om slutanvändaren svarar NEJ (= situationen är inte korrekt) ingår problemet automatiskt i handlingsplanen och slutanvändaren måste då föreslå en åtgärd för att behandla risken.

3.3 Fundera över de olika riskerna
-----------------------------------------

Du kan välja mellan olika typer av risker:

  * Prioriterad risk: avser en risk som inom branschen betraktas som en högrisk. 

    ..
    
      Exempel: Arbete på hög höjd inom byggbranschen: Stegen står på ett fast underlag


  * risk: avser aktuella risker på arbetsplatsen eller risker som är kopplade till det arbetet som utförs inom/av företaget.

    .. 

      Exempel: Alla kontorsstolar kan justeras

För att identifiera, värdera och bedöma ovanstående risktyperna är det nödvändigt att undersöka arbetsplatsen (skyddsrond, prata med medarbetarna m.m.).

 * policy: avser avtal, procedurer/processer och ledningsbeslut som rör säkerhet och hälsa på arbetsplatsen. 

    .. 
    
      Exempel: Tillverkare tillfrågas regelbundet om alternativa säkerhetsprodukter 

Dessa policypåståendena kan besvaras utan att behöva undersöka arbetsplatsen.
 

3.4 Värdering av risker
-------------------------------------
 
För varje  typ av risk kan du välja mellan två värderingsmetoder:

  * **Uppskattat risk**: genom att välja mellan **hög, medel** eller **låg risk**. 

  * **Beräknat risk**: genom att bedöma **sannolikhet, frekvens** och **allvarlighetsgrad** separat. OiRA-verktyget gör sedan en prioritering.

Slutanvändarna behöver inte värdera de följande riskerna i steget ”värdera och bedöma riskerna”:

  * Prioriterade risker (betraktas alltid som ”hög prioritet” och visas som  ”hög prio” i handlingsplanen)

  * Policy (betraktas inte som en direkt risk utan finns med som en bakomliggande orsak).


3.5 Föreslå åtgärder
---------------------

Branschen är normalt välinformerad om vilka risker som med störst sannolikhet leder till arbetsskador och sjukdomar. För att kunna hjälpa slutanvändaren med att ta fram hitta förebyggande åtgärder, kan du ta med de förslag som branschen/experterna rekommenderar. I arbetet med handlingsplanen  kan slutanvändarna välja de åtgärder som passar deras situation bäst och anpassa dem till sin egen verksamhet.

.. 

  Alla nödvändiga dokument är tillgängliga på OiRA:s webbplats http://www.oiraproject.eu/documentation
